@@ -1,6 +1,8 @@
 package Reddit::Client;
 
-our $VERSION = '1.352'; # 1.352 10/25/19: iscomment, ispost and get_type are now static 
+our $VERSION = '1.36'; # 1.36 12/22/19: lock, unlock
+						# next: marknsfw/unmarknsfw
+# 1.352 10/25/19: iscomment, ispost and get_type are now static 
 # added functions distinguish, undistinguish
 
 # 10/05/19 1.351 delete now returns result
@@ -19,7 +21,6 @@ our $VERSION = '1.352'; # 1.352 10/25/19: iscomment, ispost and get_type are now
 $VERSION = eval $VERSION;
 
 use strict;
-#use warnings;
 use Carp;
 
 use Data::Dumper   qw/Dumper/;
@@ -131,6 +132,10 @@ use constant API_DELETEFLAIR         => 43;
 use constant API_UNBAN               => 44;
 use constant API_DISTINGUISH         => 45;
 use constant API_UNDISTINGUISH       => 46;
+use constant API_LOCK                => 47;
+use constant API_UNLOCK              => 48;
+use constant API_MARKNSFW            => 49;
+use constant API_UNMARKNSFW          => 50;
 
 #===============================================================================
 # Parameters
@@ -191,6 +196,10 @@ $API[API_DELETEFLAIR   ] = ['POST', '/r/%s/api/deleteflair'   ];
 $API[API_UNBAN         ] = ['POST', '/r/%s/api/unfriend'      ];
 $API[API_DISTINGUISH   ] = ['POST', '/api/distinguish'        ];
 $API[API_UNDISTINGUISH ] = ['POST', '/api/distinguish'        ];
+$API[API_LOCK          ] = ['POST', '/api/lock'               ]; # fullname only
+$API[API_UNLOCK        ] = ['POST', '/api/unlock'             ]; # these
+$API[API_MARKNSFW      ] = ['POST', '/api/marknsfw'           ]; #
+$API[API_UNMARKNSFW    ] = ['POST', '/api/unmarknsfw'         ]; # four
 
 #===============================================================================
 # Class methods
@@ -768,7 +777,7 @@ sub get_subreddit_comments {
 #=============================================================
 sub remove {
 	my $self = shift;
-	my $fullname = shift || croak "arg 1 (fullname) is required.";
+	my $fullname = shift || die "remove: arg 1 (fullname) is required.\n";
 	
     	my $result = $self->api_json_request(
 		api  => API_REMOVE,
@@ -779,7 +788,7 @@ sub remove {
 # like remove, but sets spam flag
 sub spam {
 	my $self = shift;
-	my $fullname = shift || croak "arg 1 (fullname) is required.";
+	my $fullname = shift || croak "spam: arg 1 (fullname) is required.\n";
 	
     	my $result = $self->api_json_request(
 		api  => API_REMOVE,
@@ -789,7 +798,7 @@ sub spam {
 }
 sub approve {
 	my $self = shift;
-	my $fullname = shift || croak "arg 1 (fullname) is required.";
+	my $fullname = shift || die "approve: arg 1 (fullname) is required.\n";
 	
     	my $result = $self->api_json_request(
 		api  => API_APPROVE,
@@ -799,7 +808,7 @@ sub approve {
 }
 sub ignore_reports {
 	my $self = shift;
-	my $fullname = shift || croak "arg 1 (fullname) is required.";
+	my $fullname = shift || die "ignore_reports: arg 1 (fullname) is required.\n";
 	
 	my $result = $self->api_json_request(
 		api  => API_IGNORE_REPORTS,
@@ -807,6 +816,48 @@ sub ignore_reports {
 	);
 	return $result;
 }
+sub lock {
+	my ($self, $fullname, %param) = @_;
+	die "lock: arg 1 (fullname) is required.\n" unless $fullname;
+
+	if (!ispost($fullname) and !iscomment($fullname)) {
+		die "lock: arg 1 must be a fullname of a post or comment.\n";
+	}
+
+	my $lock = exists $param{lock} ? $param{lock} : 1;
+
+	my $result = $self->api_json_request(
+		api	 => $lock ? API_LOCK : API_UNLOCK,
+		data => { id => $fullname },
+	);
+	return $result;
+}
+sub unlock {
+	my ($self, $fullname, %param) = @_;
+	
+	return $self->lock($fullname, lock=>0);
+}
+sub nsfw {
+	my ($self, $fullname, %param) = @_;
+	die "nsfw: arg 1 (fullname) is required.\n" unless $fullname;
+
+	if (!ispost($fullname)) {
+		die "nsfw: arg 1 must be a fullname of a post or comment.\n";
+	}
+
+	my $nsfw = exists $param{nsfw} ? $param{nsfw} : 1;
+
+	my $result = $self->api_json_request(
+		api	 => $nsfw ? API_MARKNSFW : API_UNMARKNSFW,
+		data => { id => $fullname },
+	);
+	return $result;
+}
+sub unnsfw {
+	my ($self, $fullname, %param) = @_;
+	
+	return $self->nsfw($fullname, nsfw=>0);
+}
 # -ban uses the "modcontributors" oauth scope EXCEPT:
 #   -moderator and moderator_invite use "modothers"
 #   -wikibanned and wikicontributor require both modcontributors and modwiki
@@ -1982,13 +2033,13 @@ Delete a multireddit.
 
     distinguish ( $fullname,  [ sticky => 0, ] [ how => 'yes' ] )
 
-Distinguish a comment or post (moderator action). Fullname with prefix is required. Options:
+Distinguish a comment or post (moderator action). Options:
 
 =over
 
 C<sticky> Distinguish and sticky a comment. Only works for top-level comments.
 
-C<how> This option should typically be left untouched. Valid values are "yes", "no", "admin", "special". Admin is for Reddit admins only, and special is for "special" users, which the API leaves unexplained.
+C<how> This option should typically be left untouched. Valid values are "yes", "no", "admin", "special". Admin is for Reddit admins only; the rest are unexplained.
 
 =back
 
@@ -1996,7 +2047,7 @@ C<how> This option should typically be left untouched. Valid values are "yes", "
 
     edit ( $fullname, $text )
 	
-Edit a text post or comment. Unlike on the website, C<$text> can be an empty string, although to prevent accidental wipeouts it must be defined.
+Edit a text post or comment. Unlike on the website, C<$text> can be an empty string. (It can be false but must be defined.)
 
 =item edit_multi
 
@@ -2300,6 +2351,14 @@ Returns a hash of information about C<$fullname>. This will be the raw informati
 
 Returns a list of subreddits, where C<view> is one of the subreddit L<constants|https://metacpan.org/pod/Reddit::Client#CONSTANTS>: '' (i.e. home), 'subscriber', 'popular', 'new', 'contributor', or 'moderator'. Note that as of January 2018 some views, such as the default, are limited to 5,000 results. 'new' still gives infinite results (i.e. a list of all subreddits in existence). Others are untested.
 
+=item lock
+
+    lock ( $fullname, [ lock => 1 ] )
+
+Lock a post's comment section or individual comment (moderator action).
+
+Using optional argument C<lock =E<gt> 0> is the same as calling L<unlock|https://metacpan.org/pod/Reddit::Client#unlock> on the fullname.
+
 =item mark_inbox_read
 
     mark_inbox_read()
@@ -2334,7 +2393,7 @@ or
 
 Instantiate a new Reddit::Client object. Optionally authenticate at the same time. (Unless you have some reason not to, this is the recommended way to do it.) For "script"-type apps, this is done by passing in a username, password, client_id and secret. For "web"-type apps, this is done by passing in a refresh_token, client_id and secret.
 
-C<user_agent> is a string that uniquely identifies your app. The L<API rules|https://github.com/reddit/reddit/wiki/API#rules>) say it should be "something unique and descriptive, including the target platform, a unique application identifier, a version string, and your username as contact information". It also includes this warning: "NEVER lie about your user-agent. This includes spoofing popular browsers and spoofing other bots. We will ban liars with extreme prejudice." C<user_agent> is required as of version 1.2 (before, Reddit::Client would provide one if you didn't).
+C<user_agent> is a string that uniquely identifies your app. The L<API rules|https://github.com/reddit/reddit/wiki/API#rules> say it should be "something unique and descriptive, including the target platform, a unique application identifier, a version string, and your username as contact information". It also includes this warning: "NEVER lie about your user-agent. This includes spoofing popular browsers and spoofing other bots. We will ban liars with extreme prejudice." C<user_agent> is required as of version 1.2 (before, Reddit::Client would provide one if you didn't).
 
 C<subdomain> is the subdomain in links generated by Reddit::Client (for example with C<get_web_url>). You can use this to generate links to old.reddit.com to force the old version of Reddit, for example, or new.reddit.com for the new. Default www.
 
@@ -2360,6 +2419,14 @@ C<print_request_on_error>: If there is a request error, print the I<entire> HTTP
 
 =back
 
+=item nsfw
+
+    nsfw ( $fullname, [ nsfw => 1 ] )
+
+Flag a post as NSFW (moderator action).
+
+Using optional argument C<nsfw =E<gt> 0> is the same as calling L<unnsfw|https://metacpan.org/pod/Reddit::Client#unnsfw> on the fullname.
+
 =item remove
 
     remove ( $fullname )
@@ -2444,7 +2511,7 @@ Un-ban a user (moderator action).
 
     undistinguish ( $fullname )
 
-Un-distinguish a comment or post (moderator action). Fullname with prefix is required.
+Un-distinguish a comment or post (moderator action).
 
 =item unhide 
 
@@ -2452,12 +2519,26 @@ Un-distinguish a comment or post (moderator action). Fullname with prefix is req
 
 Unhide a post.
 
+=item unlock
+
+    unlock ( $fullname )
+
+Unlock a post's comment section or individual comment (moderator action).
+
+Equivalent to calling L<lock|https://metacpan.org/pod/Reddit::Client#lock>(C<$fullname>, C<lock=E<gt>0>).
+
 =item unmute
 
     unmute ( username => $username, subreddit => $subreddit )
 
 Un-mute a user (moderator action).
 
+=item unnsfw
+
+    unnsfw ( $fullname )
+
+Remove the NSFW flag from a post (moderator action). Equivalent to calling L<nsfw|https://metacpan.org/pod/Reddit::Client#nsfw>(C<$fullname>, C<nsfw=E<gt>0>).
+
 =item unsave 
 
     unsave ( $fullname )
@@ -2523,6 +2604,29 @@ Vote on a post or comment. C<$direction> can be 1, 0, or -1 (0 to clear votes).
     USER_SAVED              => 'saved'
     USER_ABOUT              => 'about'
 
+=head1 CHANGELOG
+
+Reddit::Client has tracked changes with comments at the head of the main module for years now, but this is obviously not ideal for users who just want to know what is new. A changelog text file, function, or something more nicely-formatted is planned; for now, this section will have a cut-and-paste of recent changes from the comments.
+
+=over
+    # 1.36 12/22/19: new functions lock, unlock, nsfw, unnsfw
+    # 1.352 10/25/19: iscomment, ispost and get_type are now static
+    # added functions distinguish, undistinguish
+    
+    # 10/05/19 1.351 delete now returns result
+    # 10/02/19 1.35 add_approved_user, minor housekeeping
+    # 1.341 7/30 removed warnings, they're stupid
+    # 7/30 mute and unmute
+    # 1.33 7/10 corrected 'edited' to not be boolean
+    # 5/29 1.32 unban
+    # 5/3 .315 submit_comment now returns fullname not id
+    # 4/25 .314 4/8 1.313
+    #  .314 added locked key to Comment, was this a recent Reddit change?
+    # 1.313 changed the behavior of print_request_errors
+    # 1.312 requests that fail with print_request_errors as true now die instead of
+    #       croak, which lets you capture the error message
+=back
+
 =head1 AUTHOR
 
 L<mailto:earthtone.rc@gmail.com>
